# -*- encoding:utf-8 -*-

# 経理システム (仮)
# Copyright (C) 2007 HORIKAWA Hisashi. All rights reserved.
#     http://www.nslabs.jp/bside/


require 'validating_base'

class SearchBox < ValidatingBase
  attr_accessor :text, :code
end

# ユーザ（社員）
class UsersController < ApplicationController
  before_filter :login_required
  
  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }
  
  # 検索画面
  def index
  end
  
  # 検索結果
  def search
    @search = SearchBox.new(params[:search])
    if @search.text.to_s.strip == '' && @search.code.to_s.strip == ''
      @search.errors.add_to_base '検索テキストを指定してください。'
      render :action => 'index'
      return
    end
    
    c = []; v = []
    if @search.text.to_s.strip != ''
      text = '%' + norm(@search.text.strip) + '%' # PostgreSQL限定。  TODO:fixme
      c << '(name LIKE ? OR kana_name LIKE ?)'
      v << text << text
    end
    if @search.code.to_s.strip != ''
      c << 'worker_code = ?'
      v << @search.code
    end
    @users = User.find :all,
                       :conditions => [c.join(' AND '), *v],
                       :limit => 40
  end
  
  def list
    #@worker_pages, @workers = paginate :users, :per_page => 10
    @workers = User.paginate :page => params[:page], :per_page => 20
  end

  def show
    @worker = User.find(params[:id])
  end

  def new
    @worker = User.new
  end

  def create
    @worker = User.new(params[:worker])
    if @worker.save
      flash[:notice] = 'Worker was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  def edit
    if params[:id]
      @worker = User.find(params[:id])
    else
      @worker = current_user
    end
  end

  def update
    @worker = User.find(params[:id])
    if @worker.update_attributes(params[:worker])
      flash[:notice] = 'Worker was successfully updated.'
      if current_user.division.role && current_user.division.role.keiri != 0
        redirect_to :action => 'show', :id => @worker
      else
        redirect_to '/'
      end
    else
      render :action => 'edit'
    end
  end

  def destroy
    User.find(params[:id]).destroy
    redirect_to :action => 'list'
  end
  
  # 所属部門の編集画面
  def edit_divisions
    @worker = User.find params[:id]
    @divisions = @worker.divisions
  end
  
  # 所属部門を更新
  def update_divisions
    require 'set'
    @worker = User.find params[:id]
    new_divs = params[:div].collect {|v| v.to_i}.delete_if {|v| v == 0}
    UsersDivision.transaction {
      if new_divs.empty?
        UsersDivision.delete_all ["user_id = ?", @worker.id]
      else
        UsersDivision.delete_all ["user_id = ? AND NOT division_id IN (?)",
                                  @worker.id, new_divs]
      end
      sub_divs = UsersDivision.find(:all,
                   :conditions => ["user_id = ?", @worker.id]).collect {|r| r.division_id}
      add_divs = Set.new(new_divs).subtract(sub_divs)
      add_divs.each {|d|
        r = UsersDivision.new :user => @worker, :division_id => d
        r.save!
      }
    }
    flash[:notice] = "Worker was successfully updated."
    redirect_to :action => 'show', :id => @worker
  end
end
