
# キューブを表示するためのテーブル
# 低い次元をy軸にする

class MapTable
  class Cell
    def initialize value, opt_hash
      @value = value
      @colspan = opt_hash[:colspan]
      @th = opt_hash[:th]
    end
    attr_reader :value, :colspan, :th
  end

  def initialize
    @rows = []
  end

  def map x, y, value, opt_hash = {}
    raise TypeError if !x.is_a?(Integer)
    raise TypeError if !y.is_a?(Integer)
    
    @rows[y] = [] if !@rows[y]
    @rows[y][x] = Cell.new(value, opt_hash)
  end
  
  def to_html
    s = "<table border=1>"
    @rows.each {|row|
      s << "<tr>" + to_html_row(row) + "</tr>"
    }
    s << "</table>"
    return s
  end

  private
  def to_html_row row
    s = ""
    i = 0
    while i < row.size 
      cell = row[i]
      if cell && cell.value
        s << (cell.th ? "<th" : "<td align=right") <<
             (cell.colspan ? " colspan=#{cell.colspan}>" : ">") << cell.value.to_s
        i += cell.colspan ? cell.colspan : 1
      else
        s << "<td>"
        i += 1
      end
    end
    return s
  end
end

