
# 部門、ユーザ（社員）のインポート
# 財務大将から

require 'csv'
require './import_common.rb'

establish_connection 'import_titles.log'

require '../app/models/account_title'
require '../app/models/control_division'
require '../app/models/division'
require "../app/models/user"


def import_control_divisions
  data = sjis2utf8(File.read('control_divisions.csv'))
  ControlDivision.transaction {
    idx = 0
    CSV::Reader.parse(data) {|line|
      idx += 1; next if idx == 1
      raise if line[0].to_i == 0
      r = ControlDivision.find(:first, :conditions=>["id = ?", line[0].to_i]) || 
          ControlDivision.new(:id => line[0].to_i)
      r.name = line[1]
      r.save!
    }
  }
end

# 会計部門
def import_divisions
  data = sjis2utf8(File.read(DATA_DIR + '/bumon.csv'))
  Division.transaction {
    idx = 0
    CSV::Reader.parse(data) {|line|
      idx += 1; next if idx == 1
      next if line[0].to_i != 0 && line[0].to_i != 1
      r = find_division_by_code(line[1].strip) ||
              Division.new(
                  :division_code => line[1].strip,
                  :purchase_active => 1)
      r.attributes = {
        :name => line[2],
        :kana_name => (line[3] || ""),
        :end_day => line[5],
      }
      r.save!
    }
  }
end


# 社員マスタの取り込み。
# 財務大将の社員マスタでは、所属部署がないので、ITFlowから取り込む。
def import_workers
  data = sjis2utf8 File.read('SyainMST.csv')
  
  User.transaction {
    idx = 0
    CSV::Reader.parse(data) {|line|
      idx += 1; next if idx <= 4
      r = User.find_by_worker_code(line[0].to_i) ||
          User.new(:worker_code => line[0].to_i) 
      r.attributes = {
        :name => line[1],
        :kana_name => line[2],
        :division => find_division_by_code(line[3]),
        :email => line[6],
      }
      # 同一人物で社員コードが違うことがある。何だそれ。
      if r.email
        s = User.find :first,
              :conditions => ['email = ? AND worker_code <> ?', r.email, r.worker_code]
        next if s
      end
      begin
        r.save!
      rescue
        puts "error => ", r.inspect
        raise
      end
    }
  }
end

#import_control_divisions()
import_divisions()
#import_workers()
